@@ -85,5 +85,7 @@ class Transaction:
     margin: int = field(default=None)
     rate_type: str = field(default=None)
     provider: str = field(default=None)
+    target_pay: int = field(default=None)
+    max_buy: int = field(default=None)
     # generated by server and returned
     id: uuid.UUID = field(default=None)    
\ No newline at end of file
